/**
 * COOS - Connected Objects Operating System (www.connectedobjects.org).
 *
 * Copyright (C) 2009 Telenor ASA and Tellu AS. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * You may also contact one of the following for additional information:
 * Telenor ASA, Snaroyveien 30, N-1331 Fornebu, Norway (www.telenor.no)
 * Tellu AS, Hagalokkveien 13, N-1383 Asker, Norway (www.tellu.no)
 */
package org.coos.javaframe.messages;

import org.coos.javaframe.ActorAddress;
import org.coos.javaframe.RouterAddress;

import java.io.ByteArrayOutputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

/**
 * 
 * @author Avneet Singh
 */
public class ActorAddressHelper {
	public static byte[] persist(ActorAddress aa) throws IOException {
		ByteArrayOutputStream bout = new ByteArrayOutputStream();
		DataOutputStream dout = new DataOutputStream(bout);

		if (aa == null) {
			dout.writeBoolean(false);
		} else {
			dout.writeBoolean(true);

			if (aa instanceof RouterAddress) {
				dout.writeBoolean(true);
			} else {
				dout.writeBoolean(false);
			}

			dout.write(aa.serialize());
		}

		dout.flush();

		return bout.toByteArray();
	}

	public static ActorAddress resurrect(DataInputStream din) throws IOException {
		if (din.readBoolean()) {
			if (din.readBoolean()) {
				// Is a router address
				return new RouterAddress(din);
			}

			// is a ActorAddress
			return new ActorAddress(din);
		} else {
			return null;
		}
	}
}
